@@ -18,7 +18,10 @@ from gi.repository import Gtk
 
 from bzrlib import workingtree
 from bzrlib.branch import Branch
-from bzrlib.errors import NotBranchError, NoWorkingTree
+from bzrlib.errors import (
+    NotBranchError,
+    NoWorkingTree,
+    )
 from bzrlib.revisionspec import RevisionSpec
 
 try:
@@ -123,11 +126,19 @@ class BzrProject(ControllerMixin):
 
     def open_changed_files_to_push(self, action):
         """Open the changed files in the branch that not been pushed."""
-        self.open_changed_files(self._push_tree)
+        try:
+            self.open_changed_files(self._push_tree)
+        except NotBranchError:
+            self.show_info_dialog(
+                _('This branch does not have a push location.'))
 
     def open_changed_files_from_parent(self, action):
         """Open the changed files that diverged from the parent branch."""
-        self.open_changed_files(self._parent_tree)
+        try:
+            self.open_changed_files(self._parent_tree)
+        except NotBranchError:
+            self.show_info_dialog(
+                _('This branch does not have a parent location.'))
 
     @property
     def diff_file_path(self):
